@@ -13,10 +13,11 @@ RESPONSE_TYPE_CHOICES = getattr(settings, 'OAUTH_RESPONSE_TYPE_CHOICES', ("code"
 
 READ = 1 << 1
 WRITE = 1 << 2  
+READ_WRITE = READ | WRITE
 
 DEFAULT_SCOPES = (
     (READ, 'read'),
-    (WRITE, 'write'),
+    (READ_WRITE, 'write'),
 )
 
 SCOPES = getattr(settings, 'OAUTH_SCOPES', DEFAULT_SCOPES)
