@@ -4,12 +4,15 @@ from provider.oauth2.models import AccessToken, Grant, Client, \
     
 class AccessTokenAdmin(admin.ModelAdmin):
     list_display = ('user', 'client', 'token', 'expires', 'scope',)
+    raw_id_fields = ('user',)
 
 class GrantAdmin(admin.ModelAdmin):
     list_display = ('user', 'client', 'code', 'expires',)
+    raw_id_fields = ('user',)
     
 class ClientAdmin(admin.ModelAdmin):    
-    list_display = ('user', 'url', 'redirect_uri', 'client_id', 'client_type')
+    list_display = ('url', 'user', 'redirect_uri', 'client_id', 'client_type')
+    raw_id_fields = ('user',)
 
 admin.site.register(AccessToken, AccessTokenAdmin)
 admin.site.register(Grant, GrantAdmin)
