@@ -3,7 +3,9 @@ from django.core.urlresolvers import reverse
 from django.test import TestCase
 from provider import constants, scope
 from provider.oauth2.forms import ClientForm
-from provider.oauth2.models import Client, Grant
+from provider.oauth2.models import Client, Grant, AccessToken
+from provider.oauth2.backends import BasicClientBackend, \
+    RequestParamsClientBackend, AccessTokenBackend
 from provider.templatetags.scope import scopes
 from provider.testcases import AuthorizationTest, AccessTokenTest, \
     EnforceSecureTest
@@ -38,7 +40,7 @@ class AccessTokenTest(AccessTokenTest, Mixin):
 class EnforceSecureTest(EnforceSecureTest, Mixin):
     pass
 
-class TestClientForm(TestCase, Mixin):
+class ClientFormTest(TestCase, Mixin):
     def test_client_form(self):
         form = ClientForm({'name': 'TestName', 'url': 'http://127.0.0.1:8000',
             'redirect_uri': 'http://localhost:8000/'})
@@ -50,7 +52,7 @@ class TestClientForm(TestCase, Mixin):
         self.assertTrue(form.is_valid())
         client = form.save()
         
-class TestScope(TestCase, Mixin):
+class ScopeTest(TestCase, Mixin):
     def setUp(self):
         self._scopes = constants.SCOPES
         constants.SCOPES = constants.DEFAULT_SCOPES
@@ -82,3 +84,35 @@ class TestScope(TestCase, Mixin):
         names.sort()
         
         self.assertEqual('read write', ' '.join(names))
+
+class AuthBackendTest(TestCase, Mixin):
+    fixtures = ['test_oauth2']
+
+
+
+    def test_basic_client_backend(self):
+        request = type('Request', (object,), {'META': {}})()
+        request.META['HTTP_AUTHORIZATION'] = "Basic " + "{0}:{1}".format(
+            self.get_client().client_id, 
+            self.get_client().client_secret).encode('base64')
+
+        self.assertEqual(BasicClientBackend().authenticate(request).id, 
+                         2, "Didn't return the right client.")
+
+    def test_request_params_client_backend(self):
+        request = type('Request', (object,), {'REQUEST': {}})()
+
+        request.REQUEST['client_id'] = self.get_client().client_id
+        request.REQUEST['client_secret'] = self.get_client().client_secret
+
+        self.assertEqual(RequestParamsClientBackend().authenticate(request).id, 
+                         2, "Didn't return the right client.'")
+        
+    def test_access_token_backend(self):
+        token = AccessToken.objects.create(
+            user = self.get_user(), client = self.get_client())
+    
+        self.assertIsNotNone(AccessTokenBackend().authenticate(access_token = token.token,
+                                                               client = self.get_client()))
+
+    
\ No newline at end of file
